@@ -47,9 +47,9 @@
 #include "cm-geldkarte.h"
 #include "cm-netkey.h"
 #include "cm-dinsig.h"
+#include "cm-piv.h"
 #include "cm-unknown.h"
 
-
 
 /* Object's class definition.  */
 struct _GpaCardManagerClass
@@ -118,11 +118,10 @@ static void gpa_card_manager_finalize (GObject *object);
 static GtkWidget *
 statusbar_new (GpaCardManager *cardman)
 {
-  GtkWidget *align;
   GtkWidget *hbox;
   GtkWidget *label;
 
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
   label = gtk_label_new (NULL);
   cardman->status_label = label;
@@ -132,10 +131,10 @@ statusbar_new (GpaCardManager *cardman)
   cardman->status_text = label;
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 5);
 
-  align = gtk_alignment_new (0, 1, 1, 0);
-  gtk_container_add (GTK_CONTAINER (align), hbox);
+  gtk_widget_set_halign (GTK_WIDGET (hbox), 0);
+  gtk_widget_set_valign (GTK_WIDGET (hbox), 1);
 
-  return align;
+  return hbox;
 }
 
 
@@ -226,29 +225,34 @@ scd_status_cb (void *opaque, const char *status, const char *args)
   if (!strcmp (status, "APPTYPE"))
     {
       cardman->cardtype = G_TYPE_NONE;
-      if (!strcmp (args, "OPENPGP"))
+      if (!g_ascii_strcasecmp (args, "openpgp"))
         {
           cardman->cardtype = GPA_CM_OPENPGP_TYPE;
           cardman->cardtypename = "OpenPGP";
         }
-      else if (!strcmp (args, "NKS"))
+      else if (!g_ascii_strcasecmp (args, "piv"))
+        {
+          cardman->cardtype = GPA_CM_PIV_TYPE;
+          cardman->cardtypename = "PIV";
+        }
+      else if (!g_ascii_strcasecmp (args, "nks"))
         {
           cardman->cardtype = GPA_CM_NETKEY_TYPE;
           cardman->cardtypename = "NetKey";
         }
-      else if (!strcmp (args, "DINSIG"))
+      else if (!g_ascii_strcasecmp (args, "dinsig"))
         {
           cardman->cardtype = GPA_CM_DINSIG_TYPE;
           cardman->cardtypename = "DINSIG";
         }
-      else if (!strcmp (args, "P15"))
+      else if (!g_ascii_strcasecmp (args, "P15"))
         cardman->cardtypename = "PKCS#15";
-      else if (!strcmp (args, "GELDKARTE"))
+      else if (!g_ascii_strcasecmp (args, "geldkarte"))
         {
           cardman->cardtype = GPA_CM_GELDKARTE_TYPE;
           cardman->cardtypename = "Geldkarte";
         }
-      else if (!strcmp (args, "UNDEFINED"))
+      else if (!g_ascii_strcasecmp (args, "undefined"))
         {
           cardman->cardtype = GPA_CM_UNKNOWN_TYPE;
           cardman->cardtypename = "UNKNOWN";
@@ -318,8 +322,8 @@ card_reload (GpaCardManager *cardman)
       if (cardman->app_selector
           && (gtk_combo_box_get_active
               (GTK_COMBO_BOX (cardman->app_selector)) > 0)
-          && (application = gtk_combo_box_get_active_text
-              (GTK_COMBO_BOX (cardman->app_selector))))
+          && (application = gtk_combo_box_text_get_active_text
+              (GTK_COMBO_BOX_TEXT (cardman->app_selector))))
         {
           command_buf = g_strdup_printf ("%s %s", command, application);
           command = command_buf;
@@ -455,9 +459,11 @@ card_reload (GpaCardManager *cardman)
 
 /* This function is called when the user triggers a card-reload. */
 static void
-card_reload_action (GtkAction *action, gpointer param)
+card_reload_action (GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 {
-  GpaCardManager *cardman = param;
+  // GpaCardManager *cardman = param;
+  GpaCardManager *cardman = (GpaCardManager*)user_data;
+
 
   card_reload (cardman);
 }
@@ -608,9 +614,10 @@ card_genkey (GpaCardManager *cardman)
 
 /* This function is called when the user triggers a key-generation.  */
 static void
-card_genkey_action (GtkAction *action, gpointer param)
+card_genkey_action (GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 {
-  GpaCardManager *cardman = param;
+  // GpaCardManager *cardman = param;
+  GpaCardManager *cardman = this_instance;
 
   card_genkey (cardman);
 }
@@ -630,84 +637,45 @@ watcher_cb (void *opaque, const char *filename, const char *reason)
 
 /* Handle menu item "File/Close".  */
 static void
-file_close (GtkAction *action, gpointer param)
+file_close (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
-  GpaCardManager *cardman = param;
-  gtk_widget_destroy (GTK_WIDGET (cardman));
+  // GpaCardManager *cardman = this:ubsta;
+  gtk_widget_destroy (GTK_WIDGET (this_instance));
+}
+
+/* Handle menu item "File/Close".  */
+static void
+file_quit (GSimpleAction *simple, GVariant *parameter, gpointer param)
+{
+  // GpaCardManager *cardman = this:ubsta;
+  // gtk_widget_destroy (GTK_WIDGET (this_instance));
+
+  g_application_quit (G_APPLICATION (get_gpa_application ()));
 }
 
 
 /* Construct the card manager menu and toolbar widgets and return
    them. */
 static void
-cardman_action_new (GpaCardManager *cardman, GtkWidget **menubar,
+cardman_action_new (GpaCardManager *cardman, GtkWidget **menu_bar,
 		    GtkWidget **toolbar)
 {
-  static const GtkActionEntry entries[] =
+  static const GActionEntry entries[] =
     {
-      /* Toplevel.  */
-      { "File", NULL, N_("_File"), NULL },
-      { "Edit", NULL, N_("_Edit"), NULL },
-      { "Card", NULL, N_("_Card"), NULL },
+      // Toplevel
+      { "File", NULL },
+      { "Edit", NULL },
+      { "Card", NULL },
 
-      /* File menu.  */
-      { "FileClose", GTK_STOCK_CLOSE, NULL, NULL,
-	N_("Close the window"), G_CALLBACK (file_close) },
-      { "FileQuit", GTK_STOCK_QUIT, NULL, NULL,
-	N_("Quit the program"), G_CALLBACK (gtk_main_quit) },
+      // File menu
+      { "file_close", file_close },
+      { "file_quit", file_quit },
 
-      /* Card menu.  */
-      { "CardReload", GTK_STOCK_REFRESH, NULL, NULL,
-	N_("Reload card information"), G_CALLBACK (card_reload_action) },
-      { "CardGenkey", GTK_STOCK_NEW, N_("Generate key"), NULL,
-	N_("Generate new key on card"), G_CALLBACK (card_genkey_action) },
+      { "card_reload", card_reload_action },
+      { "card_genkey", card_genkey_action },
     };
 
-  static const char *ui_description =
-    "<ui>"
-    "  <menubar name='MainMenu'>"
-    "    <menu action='File'>"
-    "      <menuitem action='FileClose'/>"
-    "      <menuitem action='FileQuit'/>"
-    "    </menu>"
-    "    <menu action='Edit'>"
-    "      <menuitem action='EditPreferences'/>"
-    "      <menuitem action='EditBackendPreferences'/>"
-    "    </menu>"
-    "    <menu action='Card'>"
-    "      <menuitem action='CardReload'/>"
-    "      <menuitem action='CardGenkey'/>"
-    "    </menu>"
-    "    <menu action='Windows'>"
-    "      <menuitem action='WindowsKeyringEditor'/>"
-    "      <menuitem action='WindowsFileManager'/>"
-    "      <menuitem action='WindowsClipboard'/>"
-    "      <menuitem action='WindowsCardManager'/>"
-    "    </menu>"
-    "    <menu action='Help'>"
-#if 0
-    "      <menuitem action='HelpContents'/>"
-#endif
-    "      <menuitem action='HelpAbout'/>"
-    "    </menu>"
-    "  </menubar>"
-    "  <toolbar name='ToolBar'>"
-    "    <toolitem action='CardReload'/>"
-#if 0
-    "    <toolitem action='CardEdit'/>"
-#endif
-    "    <separator/>"
-    "    <toolitem action='EditPreferences'/>"
-    "    <separator/>"
-    "    <toolitem action='WindowsKeyringEditor'/>"
-    "    <toolitem action='WindowsFileManager'/>"
-    "    <toolitem action='WindowsClipboard'/>"
-#if 0
-    "    <toolitem action='HelpContents'/>"
-#endif
-    "  </toolbar>"
-    "</ui>";
-
+  /*
   GtkAccelGroup *accel_group;
   GtkActionGroup *action_group;
   GtkAction *action;
@@ -738,15 +706,228 @@ cardman_action_new (GpaCardManager *cardman, GtkWidget **menubar,
       exit (EXIT_FAILURE);
     }
 
-  /* Fixup the icon theme labels which are too long for the toolbar.  */
+  // Fixup the icon theme labels which are too long for the toolbar.
   action = gtk_action_group_get_action (action_group, "WindowsKeyringEditor");
   g_object_set (action, "short_label", _("Keyring"), NULL);
   action = gtk_action_group_get_action (action_group, "WindowsFileManager");
   g_object_set (action, "short_label", _("Files"), NULL);
+  */
+
+  /*
+
+    File
+      Close
+      Quit
+
+    Edit
+      Preferences
+      Backend Preferences
+
+    Card
+      Refresh
+      Generate Key
+
+    Windows
+      Keyring Manager
+      File Manager
+      Clipboard
+      Card Manager
+
+    Help
+      About
+  */
+
+  static const char *menu_string = ""
+  "<interface>"
+  "<menu id='menu'>"
+      "<submenu>"
+        "<attribute name='label' translatable='yes'>_File</attribute>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Close</attribute>"
+          "<attribute name='action'>app.file_close</attribute>"
+        "</item>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Quit</attribute>"
+          "<attribute name='action'>app.file_quit</attribute>"
+        "</item>"
+      "</submenu>"
+      "<submenu>"
+        "<attribute name='label' translatable='yes'>Edit</attribute>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Preferences</attribute>"
+          "<attribute name='action'>app.edit_preferences</attribute>"
+        "</item>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Backend Preferences</attribute>"
+          "<attribute name='action'>app.edit_backend_preferences</attribute>"
+        "</item>"
+      "</submenu>"
+      "<submenu>"
+        "<attribute name='label' translatable='yes'>Card</attribute>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Refresh</attribute>"
+          "<attribute name='action'>app.card_reload</attribute>"
+        "</item>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Generate Key</attribute>"
+          "<attribute name='action'>app.card_genkey</attribute>"
+        "</item>"
+      "</submenu>"
+      "<submenu>"
+        "<attribute name='label' translatable='yes'>Windows</attribute>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Keyring Manager</attribute>"
+          "<attribute name='action'>app.windows_keyring_editor</attribute>"
+        "</item>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>File Manager</attribute>"
+          "<attribute name='action'>app.windows_file_manager</attribute>"
+        "</item>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Clipboard</attribute>"
+          "<attribute name='action'>app.windows_clipboard</attribute>"
+        "</item>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>Card Manager</attribute>"
+          "<attribute name='action'>app.windows_card_manager</attribute>"
+        "</item>"
+      "</submenu>"
+      "<submenu>"
+        "<attribute name='label' translatable='yes'>Help</attribute>"
+        "<item>"
+          "<attribute name='label' translatable='yes'>About</attribute>"
+          "<attribute name='action'>app.help_about</attribute>"
+        "</item>"
+      "</submenu>"
+  "</menu>"
+
+  "<object id='toolbar' class='GtkToolbar'>"
+    "<property name='visible'>True</property>"
+    "<property name='can_focus'>False</property>"
+    "<property name='show_arrow'>False</property>"
+
+    "<child>"
+      "<object class='GtkToolButton'>"
+        "<property name='visible'>True</property>"
+        "<property name='can_focus'>False</property>"
+        "<property name='use_underline'>True</property>"
+        "<property name='icon_name'>view-refresh</property>"
+        "<property name='has_tooltip'>true</property>"
+        "<property name='tooltip-text'>Reload card information</property>"
+      "</object>"
+      "<packing>"
+        "<property name='expand'>False</property>"
+        "<property name='homogeneous'>True</property>"
+      "</packing>"
+    "</child>"
+
+    "<child>"
+      "<object class='GtkSeparatorToolItem'>"
+      "</object>"
+    "</child>"
+
+    "<child>"
+      "<object class='GtkToolButton'>"
+        "<property name='visible'>True</property>"
+        "<property name='can_focus'>False</property>"
+        "<property name='use_underline'>True</property>"
+        "<property name='icon_name'>preferences-desktop</property>"
+        "<property name='has_tooltip'>true</property>"
+        "<property name='tooltip-text'>Configure the application</property>"
+      "</object>"
+      "<packing>"
+        "<property name='expand'>False</property>"
+        "<property name='homogeneous'>True</property>"
+      "</packing>"
+    "</child>"
+
+    "<child>"
+      "<object class='GtkSeparatorToolItem'>"
+      "</object>"
+    "</child>"
+
+    "<child>"
+      "<object class='GtkToolButton'>"
+        "<property name='visible'>True</property>"
+        "<property name='can_focus'>False</property>"
+        "<property name='use_underline'>True</property>"
+        "<property name='icon_name'>keyring</property>"
+        "<property name='action-name'>app.windows_keyring_editor</property>"
+        "<property name='has_tooltip'>true</property>"
+        "<property name='tooltip-text'>Open the keyring editor</property>"
+      "</object>"
+      "<packing>"
+        "<property name='expand'>False</property>"
+        "<property name='homogeneous'>True</property>"
+      "</packing>"
+    "</child>"
+
+    "<child>"
+      "<object class='GtkToolButton'>"
+        "<property name='visible'>True</property>"
+        "<property name='can_focus'>False</property>"
+        "<property name='use_underline'>True</property>"
+        "<property name='icon_name'>folder</property>"
+        "<property name='action-name'>app.windows_file_manager</property>"
+        "<property name='has_tooltip'>true</property>"
+        "<property name='tooltip-text'>Open the file manager</property>"
+      "</object>"
+      "<packing>"
+        "<property name='expand'>False</property>"
+        "<property name='homogeneous'>True</property>"
+      "</packing>"
+    "</child>"
+
+    "<child>"
+      "<object class='GtkToolButton'>"
+        "<property name='visible'>True</property>"
+        "<property name='can_focus'>False</property>"
+        "<property name='use_underline'>True</property>"
+        "<property name='icon_name'>edit-paste</property>"
+        "<property name='action-name'>app.windows_clipboard</property>"
+        "<property name='has_tooltip'>true</property>"
+        "<property name='tooltip-text'>Open the clipboard</property>"
+      "</object>"
+      "<packing>"
+        "<property name='expand'>False</property>"
+        "<property name='homogeneous'>True</property>"
+      "</packing>"
+    "</child>"
+
+  "</object>"
+
+  "</interface>";
+
+  GtkBuilder *gtk_builder = gtk_builder_new_from_string (menu_string, -1);
+  GMenuModel *menu_bar_model = G_MENU_MODEL (gtk_builder_get_object (GTK_BUILDER (gtk_builder), "menu"));
+  *menu_bar = gtk_menu_bar_new_from_model (menu_bar_model);
+
+  // GObject *grid = gtk_builder_get_object (GTK_BUILDER (gtk_builder), "toolbar");
+  *toolbar = GTK_WIDGET (gtk_builder_get_object (GTK_BUILDER (gtk_builder), "toolbar"));
+
+  GtkApplication *gpa_app = get_gpa_application ();
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_windows_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_windows_menu_g_action_entries),
+                                    cardman);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    entries,
+                                    G_N_ELEMENTS (entries),
+                                    cardman);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_help_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_help_menu_g_action_entries),
+                                    cardman);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_preferences_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_preferences_menu_g_action_entries),
+                                    cardman);
+
 
-  *menubar = gtk_ui_manager_get_widget (cardman->ui_manager, "/MainMenu");
-  *toolbar = gtk_ui_manager_get_widget (cardman->ui_manager, "/ToolBar");
-  gpa_toolbar_set_homogeneous (GTK_TOOLBAR (*toolbar), FALSE);
 }
 
 
@@ -771,6 +952,10 @@ update_card_widget (GpaCardManager *cardman, const char *error_description)
     {
       cardman->card_widget = gpa_cm_openpgp_new ();
     }
+  else if (cardman->cardtype == GPA_CM_PIV_TYPE)
+    {
+      cardman->card_widget = gpa_cm_piv_new ();
+    }
   else if (cardman->cardtype == GPA_CM_GELDKARTE_TYPE)
     {
       cardman->card_widget = gpa_cm_geldkarte_new ();
@@ -794,10 +979,40 @@ update_card_widget (GpaCardManager *cardman, const char *error_description)
       cardman->card_widget = gtk_label_new (error_description);
     }
 
-  gtk_scrolled_window_add_with_viewport
-    (GTK_SCROLLED_WINDOW (cardman->card_container), cardman->card_widget);
+  /* The following is basically what's in GTKs own
+     gtk_scrolled_window_add_with_viewport:
 
-  gtk_widget_show_all (cardman->card_widget);
+    https://salsa.debian.org/gnome-team/gtk3/-/blob/debian/master/gtk/gtkscrolledwindow.c#L4151
+  */
+
+  GtkWidget *viewport;
+  GtkBin *bin;
+  GtkWidget *child_widget;
+
+  GtkScrolledWindow *scrolled_window = GTK_SCROLLED_WINDOW (cardman->card_container);
+
+  bin = GTK_BIN (scrolled_window);
+
+  child_widget = gtk_bin_get_child (bin);
+
+  if (child_widget)
+  {
+    g_return_if_fail (GTK_IS_VIEWPORT (child_widget));
+    g_return_if_fail (gtk_bin_get_child (GTK_BIN (child_widget)) == NULL);
+
+    viewport = child_widget;
+  }
+  else
+  {
+    viewport = gtk_viewport_new (gtk_scrolled_window_get_hadjustment (scrolled_window),
+                               gtk_scrolled_window_get_vadjustment (scrolled_window));
+
+    gtk_container_add (GTK_CONTAINER (scrolled_window), viewport);
+  }
+
+  gtk_widget_show (viewport);
+
+  gtk_container_add (GTK_CONTAINER (viewport), cardman->card_widget);
 
   /* We need to do the reload after a show_all so that a card
      application may hide parts of its window.  */
@@ -815,6 +1030,7 @@ update_card_widget (GpaCardManager *cardman, const char *error_description)
       gpa_cm_openpgp_reload (cardman->card_widget, cardman->gpgagent);
       gpa_cm_geldkarte_reload (cardman->card_widget, cardman->gpgagent);
       gpa_cm_netkey_reload (cardman->card_widget, cardman->gpgagent);
+      gpa_cm_piv_reload (cardman->card_widget, cardman->gpgagent);
       gpa_cm_dinsig_reload (cardman->card_widget, cardman->gpgagent);
       gpa_cm_unknown_reload (cardman->card_widget, cardman->gpgagent);
     }
@@ -881,8 +1097,8 @@ setup_app_selector (GpaCardManager *cardman)
           p1 = strchr (p0, ':');
           if (p1)
             *p1 = 0;
-          gtk_combo_box_append_text
-            (GTK_COMBO_BOX (cardman->app_selector), p0);
+          gtk_combo_box_text_append
+            (GTK_COMBO_BOX_TEXT (cardman->app_selector), NULL, p0);
           if (p[1])
             p0 = p+1;
         }
@@ -911,7 +1127,7 @@ construct_widgets (GpaCardManager *cardman)
   gtk_widget_realize (GTK_WIDGET (cardman));
 
   /* Use a vbox to show the menu, toolbar and the file container.  */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
   /* Get the menu and the toolbar.  */
   cardman_action_new (cardman, &menubar, &toolbar);
@@ -919,9 +1135,12 @@ construct_widgets (GpaCardManager *cardman)
   gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, TRUE, 0);
 
   /* Add a fancy label that tells us: This is the card manager.  */
-  hbox1 = gtk_hbox_new (FALSE, 0);
+  hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+
+  GtkBuilder *gtk_builder = gtk_builder_new_from_string (icons_string, -1);
+
+  icon = GTK_WIDGET (gtk_builder_get_object (GTK_BUILDER (gtk_builder), "smartcard"));
 
-  icon = gtk_image_new_from_stock (GPA_STOCK_CARDMAN, GTK_ICON_SIZE_DND);
   gtk_box_pack_start (GTK_BOX (hbox1), icon, FALSE, TRUE, 0);
 
   label = gtk_label_new (NULL);
@@ -930,20 +1149,21 @@ construct_widgets (GpaCardManager *cardman)
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
   gtk_box_pack_start (GTK_BOX (hbox1), label, TRUE, TRUE, 10);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), GTK_ALIGN_START);
+  gtk_widget_set_valign (GTK_WIDGET (label), GTK_ALIGN_CENTER);
 
   /* Add a application selection box.  */
-  hbox2 = gtk_hbox_new (FALSE, 0);
+  hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   label = gtk_label_new (_("Application selection:"));
   gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, TRUE, 5);
-  cardman->app_selector = gtk_combo_box_new_text ();
-  gtk_combo_box_append_text (GTK_COMBO_BOX (cardman->app_selector),
+  cardman->app_selector = gtk_combo_box_text_new ();
+  gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (cardman->app_selector), NULL,
                              _("Auto"));
   gtk_combo_box_set_active (GTK_COMBO_BOX (cardman->app_selector), 0);
   gtk_box_pack_start (GTK_BOX (hbox2), cardman->app_selector, FALSE, TRUE, 0);
 
   /* Put Card Manager label and application selector into the same line.  */
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (GTK_BOX (hbox), hbox1, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
 
