@@ -819,16 +819,16 @@ static gint
 get_checkbox_width (void)
 {
   GtkWidget *checkbox;
-  GtkRequisition checkbox_size;
+  GtkRequisition checkbox_minimum_size, checkbox_natural_size;
 
   /* We do not save the result, as it may change with a theme change.
      In this case we will at least refresh eventually.  */
 
   checkbox = gtk_check_button_new ();
-  gtk_widget_size_request (checkbox, &checkbox_size);
+  gtk_widget_get_preferred_size (checkbox, &checkbox_minimum_size, &checkbox_natural_size);
   gtk_widget_destroy (checkbox);
 
-  return checkbox_size.width;
+  return checkbox_natural_size.width;
 }
 
 
@@ -974,7 +974,7 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 	  char *description;
 	  /* FIXME: Might need to put pages into scrolled panes if
 	     there are too many.  */
-	  page = gtk_vbox_new (FALSE, 0);
+	  page = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	  gtk_container_add (GTK_CONTAINER (dialog_notebook), page);
 
 	  description = xstrdup (comp->description);
@@ -1009,7 +1009,7 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 	  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	  gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 
-	  frame_vbox = gtk_vbox_new (FALSE, 0);
+	  frame_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	  gtk_container_add (GTK_CONTAINER (frame), frame_vbox);
 	}
 
@@ -1043,7 +1043,7 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 	      gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	      gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 
-	      frame_vbox = gtk_vbox_new (FALSE, 0);
+	      frame_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	      gtk_container_add (GTK_CONTAINER (frame), frame_vbox);
 	    }
 	  else if (option->level <= dialog_level)
@@ -1076,10 +1076,10 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 		 support multi-hbox setups for options.  Currently we
 		 only add one hbox to that vbox though.  */
 
-	      vbox = gtk_vbox_new (FALSE, 0);
+	      vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	      gtk_box_pack_start (GTK_BOX (frame_vbox), vbox, TRUE, TRUE, 0);
 
-	      hbox = gtk_hbox_new (FALSE, 0);
+	      hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	      gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
 	      /* Add the entry fields for the option, depending on its
@@ -1145,7 +1145,7 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 		  gtk_size_group_add_widget (GTK_SIZE_GROUP (size_group[0]),
 					     align);
 
-		  widget = gtk_combo_box_new_text ();
+		  widget = gtk_combo_box_text_new ();
 		  gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 		  gtk_size_group_add_widget (GTK_SIZE_GROUP (size_group[1]),
 					     widget);
@@ -1161,22 +1161,22 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 
 		  if (option->flags & GPGME_CONF_DEFAULT
 		      || option->flags & GPGME_CONF_DEFAULT_DESC)
-		    gtk_combo_box_append_text
-		      (GTK_COMBO_BOX (widget),
+		    gtk_combo_box_text_append
+		      (GTK_COMBO_BOX_TEXT (widget), NULL,
 		       (option->flags & GPGME_CONF_LIST) ?
 		       _("Use default values") : _("Use default value"));
 		  else
-		    gtk_combo_box_append_text
-		      (GTK_COMBO_BOX (widget), _("Do not use option"));
+		    gtk_combo_box_text_append
+		      (GTK_COMBO_BOX_TEXT (widget), NULL, _("Do not use option"));
 
-		  gtk_combo_box_append_text
-		    (GTK_COMBO_BOX (widget),
+		  gtk_combo_box_text_append
+		    (GTK_COMBO_BOX_TEXT (widget), NULL,
 		     (option->flags & GPGME_CONF_LIST) ?
 		     _("Use custom values") : _("Use custom value"));
 
 		  if (opt->type == OPTION_OPT_ENTRY)
-		    gtk_combo_box_append_text
-		      (GTK_COMBO_BOX (widget), _("Use default argument"));
+		    gtk_combo_box_text_append
+		      (GTK_COMBO_BOX_TEXT (widget), NULL, _("Use default argument"));
 		}
 
 	      /* Force update.  */
@@ -1203,7 +1203,7 @@ create_dialog_tabs_2 (gpgme_conf_comp_t old_conf, gpgme_conf_comp_t new_conf)
 		  char *description = xstrdup (option->description);
 
 	          percent_unescape (description, 0);
-		  gtk_widget_set_tooltip_text (vbox, description);
+		  gpa_add_tooltip (vbox, description);
 		  xfree (description);
 		}
 #endif
@@ -1296,19 +1296,22 @@ dialog_level_chooser_cb (GtkComboBox *level_chooser, gpointer *data)
       gint result;
 
       window = gtk_dialog_new_with_buttons
-	(_("GPA Message"), (GtkWindow *) dialog, GTK_DIALOG_MODAL,
-	 GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
-	 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+        (_("GPA Message"), (GtkWindow *) dialog, GTK_DIALOG_MODAL,
+        _("_Apply"), GTK_RESPONSE_APPLY,
+        _("_Cancel"), GTK_RESPONSE_CANCEL, NULL);
 
       gtk_container_set_border_width (GTK_CONTAINER (window), 5);
       gtk_dialog_set_default_response (GTK_DIALOG (window),
 				       GTK_RESPONSE_CANCEL);
 
-      hbox = gtk_hbox_new (FALSE, 0);
+      hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
       gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-      gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (window)->vbox), hbox);
-      pixmap = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO,
-					 GTK_ICON_SIZE_DIALOG);
+
+      GtkWidget *box = gtk_dialog_get_content_area( GTK_DIALOG (window));
+
+      gtk_box_pack_start (GTK_BOX (box), hbox, TRUE, TRUE, 0);
+      pixmap = gtk_image_new_from_icon_name ("dialog-information",
+        GTK_ICON_SIZE_DIALOG);
       gtk_box_pack_start (GTK_BOX (hbox), pixmap, TRUE, FALSE, 10);
       labelMessage = gtk_label_new (_("There are unapplied changes by you. "
 				      "Changing the expert setting will apply "
@@ -1358,31 +1361,32 @@ create_dialog (void)
   dialog = gtk_dialog_new_with_buttons (_("Crypto Backend Configuration"),
 					NULL /* transient parent */,
 					0,
-					NULL);
+					NULL, NULL);
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                          GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
+                          _("Apply"), GTK_RESPONSE_APPLY,
                           _("Reset"), CUSTOM_RESPONSE_RESET,
-                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                          GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+                          _("_Cancel"), GTK_RESPONSE_CANCEL,
+                          _("_OK"), GTK_RESPONSE_ACCEPT,
                           NULL );
-  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+  /* gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
                                            GTK_RESPONSE_ACCEPT,
                                            GTK_RESPONSE_CANCEL,
                                            CUSTOM_RESPONSE_RESET,
                                            GTK_RESPONSE_APPLY,
-                                           -1);
+                                           -1); */
 
   g_signal_connect ((gpointer) dialog, "response",
 		    G_CALLBACK (dialog_response), NULL);
 
-  dialog_vbox = GTK_DIALOG (dialog)->vbox;
+  dialog_vbox = gtk_dialog_get_content_area( GTK_DIALOG (dialog));
   /*  gtk_box_set_spacing (GTK_CONTAINER (dialog_vbox), 5); */
 
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
   label = gtk_label_new (_("Configure the tools of the GnuPG system."));
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
 
   label = gtk_label_new (_("Level:"));
   gtk_misc_get_padding (GTK_MISC (label), &xpad, &ypad);
@@ -1390,12 +1394,12 @@ create_dialog (void)
   gtk_misc_set_padding (GTK_MISC (label), xpad, ypad);
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-  level_chooser = gtk_combo_box_new_text ();
+  level_chooser = gtk_combo_box_text_new ();
   /* Note: We know intimately that this matches GPGME_CONF_BASIC,
      GPGME_CONF_ADVANCED and GPGME_CONF_BEGINNER.  */
-  gtk_combo_box_append_text (GTK_COMBO_BOX (level_chooser), _("Basic"));
-  gtk_combo_box_append_text (GTK_COMBO_BOX (level_chooser), _("Advanced"));
-  gtk_combo_box_append_text (GTK_COMBO_BOX (level_chooser), _("Expert"));
+  gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (level_chooser), NULL, _("Basic"));
+  gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (level_chooser), NULL, _("Advanced"));
+  gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (level_chooser), NULL, _("Expert"));
   g_signal_connect ((gpointer) level_chooser, "changed",
 		    G_CALLBACK (dialog_level_chooser_cb), NULL);
 
