@@ -151,23 +151,22 @@ gpa_file_encrypt_dialog_constructor (GType type, guint n_construct_properties,
   /* Set up the dialog */
   gpa_window_set_title (GTK_WINDOW (dialog), _("Encrypt documents"));
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-			  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			  GTK_STOCK_OK, GTK_RESPONSE_OK,
+			  _("_Cancel"), GTK_RESPONSE_CANCEL,
+			  _("_OK"), GTK_RESPONSE_OK,
                           NULL);
-  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
-                                           GTK_RESPONSE_OK,
-                                           GTK_RESPONSE_CANCEL,
-                                           -1);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK,
 				     FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
-  vboxEncrypt = GTK_DIALOG (dialog)->vbox;
+  //vboxEncrypt = GTK_DIALOG (dialog)->vbox;
+  vboxEncrypt = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
   gtk_container_set_border_width (GTK_CONTAINER (vboxEncrypt), 5);
 
   labelKeys = gtk_label_new_with_mnemonic (_("_Public Keys"));
-  gtk_misc_set_alignment (GTK_MISC (labelKeys), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (labelKeys), GTK_ALIGN_START);
+  gtk_widget_set_valign (GTK_WIDGET (labelKeys), GTK_ALIGN_CENTER);
   gtk_box_pack_start (GTK_BOX (vboxEncrypt), labelKeys, FALSE, FALSE, 0);
 
   scrollerKeys = gtk_scrolled_window_new (NULL, NULL);
