@@ -108,7 +108,7 @@ gpa_expiry_dialog_run (GtkWidget * parent, gpgme_key_t key, GDate ** new_date)
   window = gtk_dialog_new_with_buttons (_("Change expiry date"),
                                         GTK_WINDOW (parent),
                                         GTK_DIALOG_MODAL,
-                                        GTK_STOCK_OK,
+                                        _("_OK"),
                                         GTK_RESPONSE_OK,
                                         _("_Cancel"),
                                         GTK_RESPONSE_CANCEL,
@@ -117,7 +117,8 @@ gpa_expiry_dialog_run (GtkWidget * parent, gpgme_key_t key, GDate ** new_date)
   gtk_container_set_border_width (GTK_CONTAINER (window), 5);
   dialog.window = window;
 
-  vbox = GTK_DIALOG (window)->vbox;
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (window));
+  //vbox = GTK_DIALOG (window)->vbox;
   gtk_container_add (GTK_CONTAINER (window), vbox);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
