@@ -311,7 +311,7 @@ has_selection (gpointer param)
 /* Add WIDGET to the list of sensitive actions of FILEMAN.  */
 static void
 add_selection_sensitive_action (GpaFileManager *fileman,
-				 GtkAction *action,
+				 GSimpleAction *action,
 				 sensitivity_func_t callback)
 {
   g_object_set_data (G_OBJECT (action), "gpa_sensitivity", callback);
@@ -328,7 +328,7 @@ update_selection_sensitive_action (gpointer data, gpointer param)
   sensitivity_func_t func;
 
   func = g_object_get_data (G_OBJECT (data), "gpa_sensitivity");
-  gtk_action_set_sensitive (GTK_ACTION (data), func (param));
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (data), func (param));
 }
 
 
@@ -360,8 +360,8 @@ get_load_file_name (GtkWidget *parent, const gchar *title,
     {
       dialog = gtk_file_chooser_dialog_new
 	(title, GTK_WINDOW (parent), GTK_FILE_CHOOSER_ACTION_OPEN,
-	 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-	 GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL);
+	 _("_Cancel"), GTK_RESPONSE_CANCEL,
+	 _("_Open"), GTK_RESPONSE_OK, NULL);
       gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
       gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (dialog), TRUE);
     }
@@ -395,7 +395,7 @@ open_file_one (gpointer data, gpointer user_data)
 
 
 static void
-file_open (GtkAction *action, gpointer param)
+file_open (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaFileManager *fileman = param;
   GSList *filenames;
@@ -411,7 +411,7 @@ file_open (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Clear".  */
 static void
-file_clear (GtkAction *action, gpointer param)
+file_clear (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaFileManager *fileman = param;
   GtkListStore *store = GTK_LIST_STORE (gtk_tree_view_get_model
@@ -423,7 +423,7 @@ file_clear (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Verify".  */
 static void
-file_verify (GtkAction *action, gpointer param)
+file_verify (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaFileManager *fileman = param;
   GList *files;
@@ -441,7 +441,7 @@ file_verify (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Sign".  */
 static void
-file_sign (GtkAction *action, gpointer param)
+file_sign (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaFileManager *fileman = param;
   GList * files;
@@ -459,7 +459,7 @@ file_sign (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Encrypt".  */
 static void
-file_encrypt (GtkAction *action, gpointer param)
+file_encrypt (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaFileManager *fileman = param;
   GList *files;
@@ -477,7 +477,7 @@ file_encrypt (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Decrypt".  */
 static void
-file_decrypt (GtkAction *action, gpointer param)
+file_decrypt (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaFileManager *fileman = param;
   GList *files;
@@ -495,16 +495,23 @@ file_decrypt (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Close".  */
 static void
-file_close (GtkAction *action, gpointer param)
+file_close (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaFileManager *fileman = param;
   gtk_widget_destroy (GTK_WIDGET (fileman));
 }
 
+/* Handle menu item "File/Quit". */
+static void
+file_quit (GSimpleAction *simple, GVariant *parameter, gpointer param)
+{
+  g_application_quit (G_APPLICATION (get_gpa_application ()));
+}
+
 
 /* Handle menu item "Edit/Select All".  */
 static void
-edit_select_all (GtkAction *action, gpointer param)
+edit_select_all (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaFileManager *fileman = param;
 
@@ -520,14 +527,33 @@ static void
 fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
 		    GtkWidget **toolbar)
 {
-  static const GtkActionEntry entries[] =
+
+  static const GActionEntry entries[] =
+  {
+    { "File", NULL },
+    { "Edit", NULL },
+
+    { "file_open", file_open },
+    { "file_clear", file_clear },
+    { "file_sign", file_sign },
+    { "file_verify", file_verify },
+    { "file_encrypt", file_encrypt },
+    { "file_decrypt", file_decrypt },
+    { "file_close", file_close },
+    { "file_quit", file_quit },
+
+    { "edit_select_all", edit_select_all },
+  };
+
+  /*
+  static const GtkActionEntry old_entries[] =
     {
-      /* Toplevel.  */
+      // Toplevel.
       { "File", NULL, N_("_File"), NULL },
       { "Edit", NULL, N_("_Edit"), NULL },
 
-      /* File menu.  */
-      { "FileOpen", GTK_STOCK_OPEN, NULL, NULL,
+      // File menu.
+      { "FileOpen", _("_Open"), NULL, NULL,
 	N_("Open a file"), G_CALLBACK (file_open) },
       { "FileClear", GTK_STOCK_CLEAR, NULL, NULL,
 	N_("Close all files"), G_CALLBACK (file_clear) },
@@ -539,16 +565,18 @@ fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
 	N_("Encrypt the selected file"), G_CALLBACK (file_encrypt) },
       { "FileDecrypt", GPA_STOCK_DECRYPT, NULL, NULL,
 	N_("Decrypt the selected file"), G_CALLBACK (file_decrypt) },
-      { "FileClose", GTK_STOCK_CLOSE, NULL, NULL,
+      { "FileClose", _("_Close"), NULL, NULL,
 	N_("Close the window"), G_CALLBACK (file_close) },
       { "FileQuit", GTK_STOCK_QUIT, NULL, NULL,
-	N_("Quit the program"), G_CALLBACK (gtk_main_quit) },
+	N_("Quit the program"), G_CALLBACK (g_application_quit) },
 
-      /* Edit menu.  */
+      // Edit menu.
       { "EditSelectAll", GTK_STOCK_SELECT_ALL, NULL, "<control>A",
 	N_("Select all files"), G_CALLBACK (edit_select_all) }
     };
+    */
 
+    /*
   static const char *ui_description =
     "<ui>"
     "  <menubar name='MainMenu'>"
@@ -606,7 +634,285 @@ fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
 #endif
     "  </toolbar>"
     "</ui>";
+    */
 
+  static const char *menu_string = {
+    "<interface>"
+     "<menu id='main_menu'>"
+        "<submenu>"
+          "<attribute name='label' translatable='yes'>_File</attribute>"
+          "<section>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Open</attribute>"
+              "<attribute name='action'>app.file_open</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Clear</attribute>"
+              "<attribute name='action'>app.file_clear</attribute>"
+            "</item>"
+          "</section>"
+          "<section>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Sign</attribute>"
+              "<attribute name='action'>app.file_sign</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Verify</attribute>"
+              "<attribute name='action'>app.file_verify</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Encrypt</attribute>"
+              "<attribute name='action'>app.file_encrypt</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Decrypt</attribute>"
+              "<attribute name='action'>app.file_decrypt</attribute>"
+            "</item>"
+          "</section>"
+          "<section>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Close</attribute>"
+              "<attribute name='action'>app.file_close</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Quit</attribute>"
+              "<attribute name='action'>app.file_quit</attribute>"
+            "</item>"
+          "</section>"
+        "</submenu>"
+        "<submenu>"
+          "<attribute name='label' translatable='yes'>Edit</attribute>"
+          "<section>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Mark All</attribute>"
+              "<attribute name='action'>app.file_close</attribute>"
+            "</item>"
+          "</section>"
+          "<section>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Backend Settings</attribute>"
+              "<attribute name='action'>app.edit_backend_preferences</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Settings</attribute>"
+              "<attribute name='action'>app.edit_preferences</attribute>"
+            "</item>"
+          "</section>"
+        "</submenu>"
+        "<submenu>"
+          "<attribute name='label' translatable='yes'>Window</attribute>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Keyring Manager</attribute>"
+              "<attribute name='action'>app.windows_keyring_editor</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>File Manager</attribute>"
+              "<attribute name='action'>app.windows_file_manager</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Clipboard</attribute>"
+              "<attribute name='action'>app.windows_clipboard</attribute>"
+            "</item>"
+            "<item>"
+              "<attribute name='label' translatable='yes'>Card Manager</attribute>"
+              "<attribute name='action'>app.windows_card_manager</attribute>"
+            "</item>"
+        "</submenu>"
+        "<submenu>"
+          "<attribute name='label' translatable='yes'>Help</attribute>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>About</attribute>"
+            "<attribute name='action'>app.help_about</attribute>"
+          "</item>"
+        "</submenu>"
+      "</menu>"
+
+    "<object id='toolbar' class='GtkToolbar'>"
+      "<property name='visible'>True</property>"
+      "<property name='can_focus'>False</property>"
+      "<property name='show_arrow'>False</property>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>document-open</property>"
+          "<property name='action-name'>app.file_open</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Open a file</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>edit-clear</property>"
+          "<property name='action-name'>app.file_close</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Close all files</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkSeparatorToolItem'>"
+        "</object>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>sign</property>"
+          "<property name='action-name'>app.file_sign</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Sign the selected file</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>verify</property>"
+          "<property name='action-name'>app.file_verify</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Check signatures of selected files</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>encrypt</property>"
+          "<property name='action-name'>app.file_encrypt</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Encrypt the selected file</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>decrypt</property>"
+          "<property name='action-name'>app.file_decrypt</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Decrypt the selected file</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkSeparatorToolItem'>"
+        "</object>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>preferences-desktop</property>"
+          "<property name='action-name'>app.edit_preferences</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Configure the application</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkSeparatorToolItem'>"
+        "</object>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>keyring</property>"
+          "<property name='action-name'>app.windows_keyring_editor</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Open the keyring editor</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>edit-paste</property>"
+          "<property name='action-name'>app.windows_clipboard</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Open the clipboard</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>smartcard</property>"
+          "<property name='action-name'>app.windows_card_manager</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Open the card manager</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+    "</object>"
+
+    "</interface>"
+  };
+
+  /*
   GtkAccelGroup *accel_group;
   GtkActionGroup *action_group;
   GtkAction *action;
@@ -638,7 +944,7 @@ fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
       exit (EXIT_FAILURE);
     }
 
-  /* Fixup the icon theme labels which are too long for the toolbar.  */
+  // Fixup the icon theme labels which are too long for the toolbar.
   action = gtk_action_group_get_action (action_group, "WindowsKeyringEditor");
   g_object_set (action, "short_label", _("Keyring"), NULL);
 #ifdef ENABLE_CARD_MANAGER
@@ -646,7 +952,7 @@ fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
   g_object_set (action, "short_label", _("Card"), NULL);
 #endif
 
-  /* Take care of sensitiveness of widgets.  */
+  // Take care of sensitiveness of widgets.
   action = gtk_action_group_get_action (action_group, "FileSign");
   add_selection_sensitive_action (fileman, action, has_selection);
   action = gtk_action_group_get_action (action_group, "FileVerify");
@@ -659,6 +965,88 @@ fileman_action_new (GpaFileManager *fileman, GtkWidget **menubar,
   *menubar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
   *toolbar = gtk_ui_manager_get_widget (ui_manager, "/ToolBar");
   gpa_toolbar_set_homogeneous (GTK_TOOLBAR (*toolbar), FALSE);
+
+  */
+
+  GError *err = NULL;
+
+  GtkBuilder *gtk_builder = gtk_builder_new_from_string (menu_string, -1);
+
+  if (gtk_builder_add_from_string( gtk_builder, menu_string , -1, &err) == 0) {
+    printf("ERROR: %s \n", err->message);
+  }
+
+  GMenuModel *menu_bar_model = G_MENU_MODEL (gtk_builder_get_object (GTK_BUILDER (gtk_builder), "main_menu"));
+  *menubar = gtk_menu_bar_new_from_model (menu_bar_model);
+
+  /*
+  GMenuModel *popup_menu_model = G_MENU_MODEL (gtk_builder_get_object (GTK_BUILDER (gtk_builder), "popupmenu"));
+  *popup = gtk_menu_new_from_model (popup_menu_model);
+  */
+
+  GObject *grid = gtk_builder_get_object (GTK_BUILDER (gtk_builder), "toolbar");
+
+  GtkCssProvider *css_provider = gtk_css_provider_new();
+  GdkDisplay *display = gdk_display_get_default();
+  GdkScreen *screen = gdk_display_get_default_screen (display);
+  gtk_style_context_add_provider_for_screen (screen, GTK_STYLE_PROVIDER(css_provider), GTK_STYLE_PROVIDER_PRIORITY_USER);
+
+  gtk_css_provider_load_from_data(css_provider,
+                                        "#toolbar {\n"
+                                        //" padding-left: 55px;\n"
+                                        // " padding-right: 5px;\n"
+                                        // " border-radius: 3px;\n"
+                                        "}\n", -1, NULL);
+
+  GtkStyleContext *style_context;
+
+  style_context = gtk_widget_get_style_context (GTK_WIDGET (grid));
+
+
+   //gtk_widget_add_css_class (grid, "toolbar");
+
+  *toolbar = GTK_WIDGET (grid);
+
+  // We must set the name to the toolbar for css to recognize it
+  gtk_widget_set_name(*toolbar, "toolbar");
+
+  gtk_style_context_add_class (style_context, "toolbar");
+
+
+  GtkApplication *gpa_app = get_gpa_application ();
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_windows_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_windows_menu_g_action_entries),
+                                    fileman);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    entries,
+                                    G_N_ELEMENTS (entries),
+                                    fileman);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_help_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_help_menu_g_action_entries),
+                                    fileman);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_preferences_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_preferences_menu_g_action_entries),
+                                    fileman);
+  GSimpleAction *action;
+
+  action = (GSimpleAction*)g_action_map_lookup_action (G_ACTION_MAP (gpa_app), "file_sign");
+  add_selection_sensitive_action (fileman, action, has_selection);
+
+  action = (GSimpleAction*)g_action_map_lookup_action (G_ACTION_MAP (gpa_app), "file_verify");
+  add_selection_sensitive_action (fileman, action, has_selection);
+
+  action = (GSimpleAction*)g_action_map_lookup_action (G_ACTION_MAP (gpa_app), "file_encrypt");
+  add_selection_sensitive_action (fileman, action, has_selection);
+
+  action = (GSimpleAction*)g_action_map_lookup_action (G_ACTION_MAP (gpa_app), "file_decrypt");
+  add_selection_sensitive_action (fileman, action, has_selection);
 }
 
 
@@ -673,8 +1061,10 @@ dnd_drop_handler (GtkWidget *widget, GdkDragContext *context,
 {
   GdkAtom target_type = gdk_atom_intern ("text/uri-list", FALSE);
 
+  GList *targets = gdk_drag_context_list_targets(context);
+
   /* If the source offers a target we request the data from her. */
-  if (context->targets && g_list_find (context->targets,
+  if (targets && g_list_find (targets,
                                        GDK_ATOM_TO_POINTER (target_type)))
     {
       gtk_drag_get_data (widget, context, target_type, tim);
@@ -697,16 +1087,21 @@ dnd_data_received_handler (GtkWidget *widget, GdkDragContext *context,
   gboolean dnd_success = FALSE;
   gboolean delete_selection_data = FALSE;
 
+  // const guchar *our_selection_data = gtk_selection_data_get_data(selection_data);
+
   /* Is that usable by us?  */
-  if (selection_data && selection_data->length >= 0 )
+  if (selection_data && gtk_selection_data_get_length(selection_data) >= 0 )
     {
-      if (context->action == GDK_ACTION_MOVE)
+      GdkDragAction drag_action = gdk_drag_context_get_suggested_action(context);
+
+      if (drag_action == GDK_ACTION_MOVE)
         delete_selection_data = TRUE;
 
       /* Check that we got a format we can use.  */
       if (target_type == DND_TARGET_URI_LIST)
         {
-          char *p = (char *) selection_data->data;
+          //char *p = (char *) selection_data->data;
+          char *p = (char *)gtk_selection_data_get_data(selection_data);
           char **list;
           int i;
 
@@ -761,8 +1156,6 @@ file_list_new (GpaFileManager * fileman)
 			    G_CALLBACK (update_selection_sensitive_actions),
 			    fileman);
 
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (list), TRUE);
-
   scrollerFile = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy  (GTK_SCROLLED_WINDOW (scrollerFile),
 				   GTK_POLICY_AUTOMATIC,
@@ -819,7 +1212,7 @@ gpa_file_manager_constructor (GType type,
   gtk_widget_realize (GTK_WIDGET (fileman));
 
   /* Use a vbox to show the menu, toolbar and the file container.  */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
   /* Get the menu and the toolbar.  */
   fileman_action_new (fileman, &menubar, &toolbar);
@@ -828,10 +1221,10 @@ gpa_file_manager_constructor (GType type,
 
 
   /* Add a fancy label that tells us: This is the file manager.  */
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 5);
 
-  icon = gtk_image_new_from_stock ("gtk-directory", GTK_ICON_SIZE_DND);
+  icon = gtk_image_new_from_icon_name ("folder", GTK_ICON_SIZE_DND);
   gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, TRUE, 0);
 
   label = gtk_label_new (NULL);
@@ -840,7 +1233,9 @@ gpa_file_manager_constructor (GType type,
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 10);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), GTK_ALIGN_START);
+  gtk_widget_set_valign (GTK_WIDGET (label), GTK_ALIGN_CENTER);
+
 
 
   /* Third a hbox with the file list.  */
@@ -851,7 +1246,7 @@ gpa_file_manager_constructor (GType type,
 			     pl + 5, pr + 5);
   gtk_box_pack_start (GTK_BOX (vbox), align, TRUE, TRUE, 0);
 
-  file_box = gtk_hbox_new (TRUE, 0);
+  file_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   file_frame = file_list_new (fileman);
   gtk_box_pack_start (GTK_BOX (file_box), file_frame, TRUE, TRUE, 0);
   gtk_container_add (GTK_CONTAINER (align), file_box);
