@@ -216,7 +216,7 @@ details_page_fill_key (GpaKeyDetails *kdt, gpgme_key_t key)
   g_free (text);
 #endif
 
-  gtk_widget_hide_all (kdt->details_num_label);
+  gtk_widget_hide (kdt->details_num_label);
   gtk_widget_show_all (kdt->details_table);
   gtk_widget_set_no_show_all (kdt->details_num_label, TRUE);
   gtk_widget_set_no_show_all (kdt->details_table, FALSE);
@@ -241,7 +241,7 @@ details_page_fill_num_keys (GpaKeyDetails *kdt, gint num_key)
     }
 
   gtk_widget_show_all (kdt->details_num_label);
-  gtk_widget_hide_all (kdt->details_table);
+  gtk_widget_hide (kdt->details_table);
   gtk_widget_set_no_show_all (kdt->details_num_label, FALSE);
   gtk_widget_set_no_show_all (kdt->details_table, TRUE);
 
@@ -253,22 +253,24 @@ details_page_fill_num_keys (GpaKeyDetails *kdt, gint num_key)
 
 /* Add a single row to the details table.  */
 static GtkWidget *
-add_details_row (GtkWidget *table, gint row, gchar *text,
+add_details_row (GtkWidget *grid, gint row, gchar *text,
                  gboolean selectable)
 {
   GtkWidget *widget;
 
   widget = gtk_label_new (text);
-  gtk_table_attach (GTK_TABLE (table), widget, 0, 1, row, row + 1,
-                    GTK_FILL, GTK_FILL, 0, 0);
-  gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.0);
+  gtk_grid_attach (GTK_GRID (grid), widget, 0, row, 1, 1);
+  gtk_widget_set_halign (GTK_WIDGET (widget), GTK_ALIGN_END);
+  gtk_widget_set_valign (GTK_WIDGET (widget), GTK_ALIGN_CENTER);
 
   widget = gtk_label_new ("");
   gtk_label_set_selectable (GTK_LABEL (widget), selectable);
-  gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (widget), GTK_ALIGN_START);
+  gtk_widget_set_valign (GTK_WIDGET (widget), GTK_ALIGN_CENTER);
 
-  gtk_table_attach (GTK_TABLE (table), widget, 1, 2, row, row + 1,
-                    GTK_FILL | GTK_EXPAND, 0, 0, 0);
+  gtk_widget_set_margin_start (GTK_WIDGET (widget), 5);
+
+  gtk_grid_attach (GTK_GRID (grid), widget, 1, row, 1, 1);
 
   return widget;
 }
@@ -277,7 +279,7 @@ add_details_row (GtkWidget *table, gint row, gchar *text,
 static void
 construct_details_page (GpaKeyDetails *kdt)
 {
-  GtkWidget *table;
+  GtkWidget *grid;
   GtkWidget *label;
   GtkWidget *vbox;
   GtkWidget *scrolled;
@@ -293,7 +295,7 @@ construct_details_page (GpaKeyDetails *kdt)
                                   GTK_POLICY_AUTOMATIC);
   viewport = gtk_viewport_new (NULL, NULL);
   gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport), GTK_SHADOW_NONE);
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
   gtk_container_add (GTK_CONTAINER (viewport), vbox);
   gtk_container_add (GTK_CONTAINER (scrolled), viewport);
@@ -302,35 +304,35 @@ construct_details_page (GpaKeyDetails *kdt)
   kdt->details_num_label = label;
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 
-  table = gtk_table_new (2, 7, FALSE);
-  kdt->details_table = table;
-  gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
-  gtk_table_set_row_spacing (GTK_TABLE (table), 0, 2);
-  gtk_table_set_col_spacing (GTK_TABLE (table), 0, 4);
+  grid = gtk_grid_new ();
+  kdt->details_table = grid;
+  gtk_box_pack_start (GTK_BOX (vbox), grid, TRUE, TRUE, 0);
+  // gtk_table_set_row_spacing (GTK_TABLE (grid), 0, 2);
+  // gtk_table_set_col_spacing (GTK_TABLE (grid), 0, 4);
 
   table_row = 0;
   kdt->detail_public_private = add_details_row
-    (table, table_row++, "", TRUE);
+    (grid, table_row++, "", TRUE);
   kdt->detail_capabilities = add_details_row
-    (table, table_row++, "", TRUE);
+    (grid, table_row++, "", TRUE);
   kdt->detail_name = add_details_row
-    (table, table_row++, _("User name:"), TRUE);
+    (grid, table_row++, _("User name:"), TRUE);
   kdt->detail_fingerprint = add_details_row
-    (table, table_row++, _("Fingerprint:"), TRUE);
+    (grid, table_row++, _("Fingerprint:"), TRUE);
   kdt->detail_key_id = add_details_row
-    (table, table_row++, _("Key ID:"), TRUE);
+    (grid, table_row++, _("Key ID:"), TRUE);
   kdt->detail_expiry = add_details_row
-    (table, table_row++, _("Expires at:"), FALSE);
+    (grid, table_row++, _("Expires at:"), FALSE);
   kdt->detail_owner_trust = add_details_row
-    (table, table_row++, _("Owner Trust:"), FALSE);
+    (grid, table_row++, _("Owner Trust:"), FALSE);
   kdt->detail_key_trust = add_details_row
-    (table, table_row++, _("Key validity:"), FALSE);
+    (grid, table_row++, _("Key validity:"), FALSE);
   kdt->detail_key_type = add_details_row
-    (table, table_row++, _("Key type:"), FALSE);
+    (grid, table_row++, _("Key type:"), FALSE);
   kdt->detail_creation = add_details_row
-    (table, table_row++, _("Created at:"), FALSE);
+    (grid, table_row++, _("Created at:"), FALSE);
   kdt->detail_last_update = add_details_row
-    (table, table_row++, _("Last update:"), FALSE);
+    (grid, table_row++, _("Last update:"), FALSE);
 
   gtk_notebook_append_page (GTK_NOTEBOOK (kdt), scrolled,
                             gtk_label_new (_("Details")));
@@ -364,7 +366,7 @@ build_uid_page (GpaKeyDetails *kdt, gpgme_key_t key)
     return;
 
   /* Create a new page.  */
-  vbox = gtk_vbox_new (FALSE, 5);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
   scrolled = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
@@ -421,16 +423,16 @@ build_signatures_page (GpaKeyDetails *kdt, gpgme_key_t key)
   if (!key)
     return;
 
-  vbox = gtk_vbox_new (FALSE, 5);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
   /* If there is more than one OpenPGP UID, we need a select button.  */
   if (key->uids && key->uids->next && key->protocol == GPGME_PROTOCOL_OpenPGP)
     {
-      hbox = gtk_hbox_new (FALSE, 5);
+      hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
       label = gtk_label_new (_("Show signatures on user name:"));
       gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-      kdt->signatures_uids = gtk_combo_box_new_text ();
+      kdt->signatures_uids = gtk_combo_box_text_new ();
       gtk_box_pack_start (GTK_BOX (hbox), kdt->signatures_uids, TRUE, TRUE, 0);
       gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
@@ -486,12 +488,12 @@ build_signatures_page (GpaKeyDetails *kdt, gpgme_key_t key)
       combo = GTK_COMBO_BOX (kdt->signatures_uids);
       gtk_widget_set_size_request (GTK_WIDGET (combo), 0, -1);
 
-      gtk_combo_box_append_text (combo, _("All signatures"));
+      gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combo), NULL, _("All signatures"));
       gtk_combo_box_set_active (combo, 0);
       for (i=1, uid = key->uids; uid; i++, uid = uid->next)
 	{
 	  gchar *uid_string = gpa_gpgme_key_get_userid (uid);
-	  gtk_combo_box_append_text (combo, uid_string);
+	  gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combo), NULL, uid_string);
 	  g_free (uid_string);
 	}
 
@@ -531,7 +533,7 @@ build_subkeys_page (GpaKeyDetails *kdt, gpgme_key_t key)
     return;
 
   /* Create a new page.  */
-  vbox = gtk_vbox_new (FALSE, 5);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
   scrolled = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
@@ -585,7 +587,7 @@ build_tofu_page (GpaKeyDetails *kdt, gpgme_key_t key)
     return;
 
   /* Create a new page.  */
-  vbox = gtk_vbox_new (FALSE, 5);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
   scrolled = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
