@@ -83,6 +83,7 @@ static char *dummy_arg;
 
 static gpa_args_t args;
 
+static GtkApplication *gpa_application;
 
 /* The copyright notice.  */
 static const char *copyright =
@@ -160,7 +161,15 @@ get_locale_dir (void)
 
   if (! GetModuleFileNameA (0, name, sizeof (name) - 30))
     return NULL;
-  p = strrchr (name, '\\');
+
+  /* If installed under bin assume that share is on the same
+     hierarchy as the bin subdirectory. Otherwise assume that
+     share is a subdirectory of the gpa.exe location. */
+  p = strstr (name, "\\bin\\");
+  if (!p)
+    {
+      p = strrchr (name, '\\');
+    }
   if (!p)
     {
       *name = '\\';
@@ -181,7 +190,7 @@ i18n_init (void)
 #ifdef ENABLE_NLS
   char *tmp;
 
-  gtk_set_locale ();
+  setlocale(LC_ALL, "");
   bind_textdomain_codeset (PACKAGE, "UTF-8");
 
   tmp = get_locale_dir ();
@@ -223,7 +232,7 @@ close_main_window (GtkWidget *widget, gpointer param)
 
 /* Show the key manager dialog.  */
 void
-gpa_open_key_manager (GtkAction *action, void *data)
+gpa_open_key_manager (GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 {
   GtkWidget *widget;
   gboolean created;
@@ -232,7 +241,7 @@ gpa_open_key_manager (GtkAction *action, void *data)
   if (created)
     g_signal_connect (G_OBJECT (widget), "destroy",
                       G_CALLBACK (quit_if_no_window), NULL);
-
+  gtk_window_set_application (GTK_WINDOW (widget), gpa_application);
   gtk_widget_show_all (widget);
   gtk_window_present (GTK_WINDOW (widget));
 }
@@ -240,65 +249,78 @@ gpa_open_key_manager (GtkAction *action, void *data)
 
 /* Show the clipboard dialog.  */
 void
-gpa_open_clipboard (GtkAction *action, void *data)
+gpa_open_clipboard (GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 {
   /* FIXME: Shouldn't this connect only happen if the instance is
      created the first time?  Looks like a memory leak to me.  Right:
      although the closure is ref counted an internal data object will
      get allocated.  */
+  GtkWidget *widget;
+  widget = gpa_clipboard_get_instance();
+
   g_signal_connect (G_OBJECT (gpa_clipboard_get_instance ()), "destroy",
 		    G_CALLBACK (quit_if_no_window), NULL);
-  gtk_widget_show_all (gpa_clipboard_get_instance ());
+  gtk_window_set_application (GTK_WINDOW (widget), gpa_application);
+  gtk_widget_show_all (widget);
 
-  gtk_window_present (GTK_WINDOW (gpa_clipboard_get_instance ()));
+  gtk_window_present (GTK_WINDOW (widget));
 }
 
 
 /* Show the filemanager dialog.  */
 void
-gpa_open_filemanager (GtkAction *action, void *data)
+gpa_open_filemanager (GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 {
   /* FIXME: Shouldn't this connect only happen if the instance is
      created the first time?  Looks like a memory leak to me.  */
-  g_signal_connect (G_OBJECT (gpa_file_manager_get_instance ()), "destroy",
+  GtkWidget *widget;
+
+  widget = gpa_file_manager_get_instance();
+
+  g_signal_connect (G_OBJECT (widget), "destroy",
 		    G_CALLBACK (quit_if_no_window), NULL);
+  gtk_window_set_application (GTK_WINDOW (widget), gpa_application);
   gtk_widget_show_all (gpa_file_manager_get_instance ());
 
-  gtk_window_present (GTK_WINDOW (gpa_file_manager_get_instance ()));
+  gtk_window_present (GTK_WINDOW (widget));
 }
 
 /* Show the card manager.  */
 #ifdef ENABLE_CARD_MANAGER
 void
-gpa_open_cardmanager (GtkAction *action, void *data)
+gpa_open_cardmanager (GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 {
   /* FIXME: Shouldn't this connect only happen if the instance is
      created the first time?  Looks like a memory leak to me.  */
-  g_signal_connect (G_OBJECT (gpa_card_manager_get_instance ()), "destroy",
-		    G_CALLBACK (quit_if_no_window), NULL);
-  gtk_widget_show_all (gpa_card_manager_get_instance ());
+  GtkWidget *widget = gpa_card_manager_get_instance();
 
-  gtk_window_present (GTK_WINDOW (gpa_card_manager_get_instance ()));
+  g_signal_connect (G_OBJECT (widget), "destroy",
+		    G_CALLBACK (quit_if_no_window), NULL);
+  gtk_window_set_application (GTK_WINDOW (widget), gpa_application);
+  gtk_widget_show_all (GTK_WIDGET (widget));
+
+  gtk_window_present (GTK_WINDOW (widget));
 }
 #endif /*ENABLE_CARD_MANAGER*/
 
 /* Show the settings dialog.  */
 void
-gpa_open_settings_dialog (GtkAction *action, void *data)
+gpa_open_settings_dialog (GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 {
-  settings_dlg_new (data);
+  settings_dlg_new (user_data);
 }
 
 
 /* Show the backend configuration dialog.  */
 void
-gpa_open_backend_config_dialog (GtkAction *action, void *data)
+gpa_open_backend_config_dialog (GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 {
   if (!backend_config_dialog)
     {
       backend_config_dialog = gpa_backend_config_dialog_new ();
       g_signal_connect (G_OBJECT (backend_config_dialog), "destroy",
 			G_CALLBACK (close_main_window), &backend_config_dialog);
+      gtk_window_set_application (GTK_WINDOW (backend_config_dialog), gpa_application);
       gtk_widget_show_all (backend_config_dialog);
     }
 
@@ -345,7 +367,7 @@ open_requested_window (int argc, char **argv, int use_server)
           err = gpa_send_to_server ("START_KEYMANAGER");
         }
       else
-        gpa_open_key_manager (NULL, NULL);
+        gpa_open_key_manager (NULL, NULL, NULL);
     }
 
   if (args.start_clipboard && (optind >= argc))
@@ -356,7 +378,7 @@ open_requested_window (int argc, char **argv, int use_server)
           err = gpa_send_to_server ("START_CLIPBOARD");
         }
       else
-        gpa_open_clipboard (NULL, NULL);
+        gpa_open_clipboard (NULL, NULL, NULL);
     }
 
   if (args.start_file_manager || (optind < argc))
@@ -368,7 +390,7 @@ open_requested_window (int argc, char **argv, int use_server)
           err = gpa_send_to_server ("START_FILEMANAGER");
         }
       else
-        gpa_open_filemanager (NULL, NULL);
+        gpa_open_filemanager (NULL, NULL, NULL);
     }
 
 #ifdef ENABLE_CARD_MANAGER
@@ -380,7 +402,7 @@ open_requested_window (int argc, char **argv, int use_server)
           err = gpa_send_to_server ("START_CARDMANAGER");
         }
       else
-        gpa_open_cardmanager (NULL, NULL);
+        gpa_open_cardmanager (NULL, NULL, NULL);
     }
 #endif /*ENABLE_CARD_MANAGER*/
 
@@ -392,7 +414,7 @@ open_requested_window (int argc, char **argv, int use_server)
           err = gpa_send_to_server ("START_CONFDIALOG");
         }
       else
-        gpa_open_settings_dialog (NULL, NULL);
+        gpa_open_settings_dialog (NULL, NULL, NULL);
     }
 
   /* If there are any command line arguments that are not options, try
@@ -417,6 +439,41 @@ open_requested_window (int argc, char **argv, int use_server)
 }
 
 
+struct gpa_start_data {
+  int argc;
+  char **argv;
+  int start_only_server;
+};
+
+static void activate (GtkApplication *app, gpointer user_data)
+{
+  GList *list;
+
+  struct gpa_start_data *start_data = (struct gpa_start_data *) user_data;
+
+  int argc = start_data->argc;
+  char **argv = start_data->argv;
+
+  list = gtk_application_get_windows (app);
+
+  if (list)
+    {
+      gtk_window_present (GTK_WINDOW (list->data));
+    }
+  else
+    {
+      /* Startup whatever has been requested by the user.  */
+      if (!args.start_only_server)
+      open_requested_window (argc, argv, 0);
+    }
+}
+
+
+GtkApplication *get_gpa_application()
+{
+  return gpa_application;
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -424,6 +481,7 @@ main (int argc, char *argv[])
   GOptionContext *context;
   char *configname = NULL;
   char *keyservers_configname = NULL;
+  int status;
 
   /* Under W32 logging is disabled by default to prevent MS Windows NT
      from opening a console.  */
@@ -480,6 +538,8 @@ main (int argc, char *argv[])
                                    "XProperty");
 #endif
 
+  gpa_application = gtk_application_new ("org.gnupg.gpa", 0);
+
   /* Default icon for all windows.  */
   gtk_window_set_default_icon_from_file (GPA_DATADIR "/gpa.png", &err);
   if (err)
@@ -568,7 +628,6 @@ main (int argc, char *argv[])
         args.start_clipboard = TRUE;
     }
 
-
   /* Check whether we need to start a server or to simply open a
      window in an already running server.  */
   switch (gpa_check_server ())
@@ -609,11 +668,16 @@ main (int argc, char *argv[])
   /* Initialize the file watch facility.  */
   gpa_init_filewatch ();
 
-  /* Startup whatever has been requested by the user.  */
-  if (!args.start_only_server)
-    open_requested_window (argc, argv, 0);
+  struct gpa_start_data start_data;
+  start_data.argv = argv;
+  start_data.argc = argc;
+  start_data.start_only_server = args.start_only_server;
 
-  gtk_main ();
+  g_signal_connect (gpa_application, "activate", G_CALLBACK(activate), &start_data);
 
-  return 0;
+  status = g_application_run (G_APPLICATION (gpa_application), start_data.argc, start_data.argv);
+
+  g_object_unref (gpa_application);
+
+  return status;
 }
