@@ -485,28 +485,31 @@ ignore_key_trust (gpgme_key_t key, GtkWidget *parent)
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
-  hbox = gtk_hbox_new (FALSE, 6);
-  image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
-				    GTK_ICON_SIZE_DIALOG);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  image = gtk_image_new_from_icon_name("dialog-warning", GTK_ICON_SIZE_DIALOG);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
-  vbox = gtk_vbox_new (FALSE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-  gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox);
+  GtkWidget *box = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  gtk_box_pack_start (GTK_BOX (box), hbox, TRUE, TRUE, 0);
 
   label = gtk_label_new (_("You are going to encrypt a document using "
 			   "the following key:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
   key_info = gpa_key_info_new (key);
   gtk_box_pack_start (GTK_BOX (vbox), key_info, FALSE, TRUE, 5);
   label = gtk_label_new (_("However, it is not certain that the key belongs "
 			   "to that person."));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
   label = gtk_label_new (NULL);
   gtk_label_set_markup (GTK_LABEL (label),
 			_("Do you <b>really</b> want to use this key?"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
 
   gtk_widget_show_all (dialog);
@@ -533,21 +536,23 @@ revoked_key (gpgme_key_t key, GtkWidget *parent)
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
-  hbox = gtk_hbox_new (FALSE, 6);
-  image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_ERROR,
-				    GTK_ICON_SIZE_DIALOG);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  image = gtk_image_new_from_icon_name("dialog-error", GTK_ICON_SIZE_DIALOG);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
-  vbox = gtk_vbox_new (FALSE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-  gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox);
+  GtkWidget *box = gtk_dialog_get_content_area( GTK_DIALOG(dialog));
+  gtk_box_pack_start (GTK_BOX (box), hbox, TRUE, TRUE, 0);
 
   label = gtk_label_new (_("The following key has been revoked by its owner:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
   key_info = gpa_key_info_new (key);
   gtk_box_pack_start (GTK_BOX (vbox), key_info, FALSE, TRUE, 5);
   label = gtk_label_new (_("And can not be used for encryption."));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
 
   gtk_widget_show_all (dialog);
@@ -573,25 +578,27 @@ expired_key (gpgme_key_t key, GtkWidget *parent)
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
-  hbox = gtk_hbox_new (FALSE, 6);
-  image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_ERROR,
-				    GTK_ICON_SIZE_DIALOG);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  image = gtk_image_new_from_icon_name("dialog-error", GTK_ICON_SIZE_DIALOG);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
-  vbox = gtk_vbox_new (FALSE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-  gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox);
+  GtkWidget *box = gtk_dialog_get_content_area( GTK_DIALOG(dialog));
+  gtk_box_pack_start (GTK_BOX (box), hbox, TRUE, TRUE, 0);
 
   /* Fixme: We leak the date string.  */
   message = g_strdup_printf (_("The following key expired on %s:"),
                              gpa_expiry_date_string
                              (key->subkeys->expires));
   label = gtk_label_new (message);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
   key_info = gpa_key_info_new (key);
   gtk_box_pack_start (GTK_BOX (vbox), key_info, FALSE, TRUE, 5);
   label = gtk_label_new (_("And can not be used for encryption."));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 5);
 
   gtk_widget_show_all (dialog);
