@@ -18,6 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#include <config.h>
+
 #include <glib.h>
 
 #ifdef G_OS_UNIX
@@ -36,10 +38,10 @@
 
 /* Internal functions */
 static gboolean gpa_key_expire_operation_idle_cb (gpointer data);
-static void gpa_key_expire_operation_done_error_cb (GpaContext *context, 
+static void gpa_key_expire_operation_done_error_cb (GpaContext *context,
 						    gpg_error_t err,
 						    GpaKeyExpireOperation *op);
-static void gpa_key_expire_operation_done_cb (GpaContext *context, 
+static void gpa_key_expire_operation_done_cb (GpaContext *context,
 					      gpg_error_t err,
 					      GpaKeyExpireOperation *op);
 
@@ -99,7 +101,7 @@ static void
 gpa_key_expire_operation_class_init (GpaKeyExpireOperationClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  
+
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->constructor = gpa_key_expire_operation_constructor;
@@ -112,7 +114,7 @@ gpa_key_expire_operation_class_init (GpaKeyExpireOperationClass *klass)
 		  G_SIGNAL_RUN_FIRST,
 		  G_STRUCT_OFFSET (GpaKeyExpireOperationClass, new_expiration),
 		  NULL, NULL,
-		  gtk_marshal_VOID__POINTER_POINTER,
+		  g_cclosure_marshal_VOID__POINTER,
 		  G_TYPE_NONE, 2,
 		  G_TYPE_POINTER,
 		  G_TYPE_POINTER);
@@ -122,7 +124,7 @@ GType
 gpa_key_expire_operation_get_type (void)
 {
   static GType key_expire_operation_type = 0;
-  
+
   if (!key_expire_operation_type)
     {
       static const GTypeInfo key_expire_operation_info =
@@ -137,12 +139,12 @@ gpa_key_expire_operation_get_type (void)
         0,              /* n_preallocs */
         (GInstanceInitFunc) gpa_key_expire_operation_init,
       };
-      
-      key_expire_operation_type = g_type_register_static 
+
+      key_expire_operation_type = g_type_register_static
 	(GPA_KEY_OPERATION_TYPE, "GpaKeyExpireOperation",
 	 &key_expire_operation_info, 0);
     }
-  
+
   return key_expire_operation_type;
 }
 
@@ -154,7 +156,7 @@ GpaKeyExpireOperation*
 gpa_key_expire_operation_new (GtkWidget *window, GList *keys)
 {
   GpaKeyExpireOperation *op;
-  
+
   op = g_object_new (GPA_KEY_EXPIRE_OPERATION_TYPE,
 		     "window", window,
 		     "keys", keys,
@@ -165,60 +167,65 @@ gpa_key_expire_operation_new (GtkWidget *window, GList *keys)
 
 /* Internal */
 
-static gboolean
+static gpg_error_t
 gpa_key_expire_operation_start (GpaKeyExpireOperation *op)
-{ 
-  gpgme_key_t key = gpa_key_operation_current_key (GPA_KEY_OPERATION (op));
+{
+  gpg_error_t err;
+  gpgme_key_t key;
   GDate *date;
 
-  if (gpa_expiry_dialog_run (GPA_OPERATION (op)->window, key, &date))
+  key = gpa_key_operation_current_key (GPA_KEY_OPERATION (op));
+  g_return_val_if_fail (key, gpg_error (GPG_ERR_CANCELED));
+
+  if (! gpa_expiry_dialog_run (GPA_OPERATION (op)->window, key, &date))
+    return gpg_error (GPG_ERR_CANCELED);
+
+  err = gpa_gpgme_edit_expire_start (GPA_OPERATION(op)->context, key, date);
+  op->date = date;
+  if (err)
     {
-      gpg_error_t err;
-      err = gpa_gpgme_edit_expire_start (GPA_OPERATION(op)->context, key,
-					 date);
-      op->date = date;
-      if (gpg_err_code (err) != GPG_ERR_NO_ERROR)
-	{
-	  gpa_gpgme_warning (err);
-	  return FALSE;
-	}
+      gpa_gpgme_warning (err);
+      return err;
     }
-  else
-    {
-      return FALSE;
-    }
-  return TRUE;
+
+  return 0;
 }
 
+
 static gboolean
 gpa_key_expire_operation_idle_cb (gpointer data)
 {
   GpaKeyExpireOperation *op = data;
+  gpg_error_t err;
 
-  if (!gpa_key_expire_operation_start (op))
-    {
-      g_signal_emit_by_name (GPA_OPERATION (op), "completed");
-    }
+  err = gpa_key_expire_operation_start (op);
+  if (err)
+    g_signal_emit_by_name (GPA_OPERATION (op), "completed", err);
 
   return FALSE;
 }
 
+
 static void
 gpa_key_expire_operation_next (GpaKeyExpireOperation *op)
 {
-  if (!GPA_KEY_OPERATION (op)->current ||
-      !gpa_key_expire_operation_start (op))
+  gpg_error_t err = 0;
+
+  if (GPA_KEY_OPERATION (op)->current)
     {
-      if (op->modified_keys > 0)
-	{
-	  g_signal_emit_by_name (GPA_OPERATION (op), "changed_wot");
-	}
-      g_signal_emit_by_name (GPA_OPERATION (op), "completed");
+      err = gpa_key_expire_operation_start (op);
+      if (! err)
+	return;
     }
+
+  if (op->modified_keys > 0)
+    g_signal_emit_by_name (GPA_OPERATION (op), "changed_wot");
+  g_signal_emit_by_name (GPA_OPERATION (op), "completed", err);
 }
 
-static void 
-gpa_key_expire_operation_done_error_cb (GpaContext *context, 
+
+static void
+gpa_key_expire_operation_done_error_cb (GpaContext *context,
                                         gpg_error_t err,
                                         GpaKeyExpireOperation *op)
 {
@@ -230,38 +237,38 @@ gpa_key_expire_operation_done_error_cb (GpaContext *context,
       /* Ignore these */
       break;
     case GPG_ERR_BAD_PASSPHRASE:
-      gpa_window_error (_("Wrong passphrase!"), GPA_OPERATION (op)->window);
+      gpa_show_warn (GPA_OPERATION (op)->window, GPA_OPERATION (op)->context,
+                     _("Wrong passphrase!"));
       break;
     case GPG_ERR_INV_TIME:
-      gpa_window_error 
-        (_("Invalid time given.\n"
-           "(you may not set the expiration time to the past.)"),
-         GPA_OPERATION (op)->window);
+      gpa_show_warn (GPA_OPERATION (op)->window, GPA_OPERATION (op)->context,
+                     _("Invalid time given.\n"
+                       "(you may not set the expiration time to the past.)"));
       break;
     default:
       gpa_gpgme_warning (err);
+      gpa_gpgme_warn (err, NULL, GPA_OPERATION (op)->context);
       break;
     }
 }
 
-static void 
+static void
 gpa_key_expire_operation_done_cb (GpaContext *context,
                                   gpg_error_t err,
                                   GpaKeyExpireOperation *op)
 {
-  if (gpg_err_code (err) == GPG_ERR_NO_ERROR)
-    {
-      /* The expiration was changed */
-      g_signal_emit_by_name (op, "new_expiration", 
-			     GPA_KEY_OPERATION (op)->current->data, op->date);
-    }
-  /* Clean previous date */
+  if (! err)
+    /* The expiration was changed.  */
+    g_signal_emit_by_name (op, "new_expiration",
+			   GPA_KEY_OPERATION (op)->current->data, op->date);
+
+  /* Clean previous date.  */
   if (op->date)
     {
       g_date_free (op->date);
       op->date = NULL;
     }
-  /* Go to the next key */
+  /* Go to the next key.  */
   GPA_KEY_OPERATION (op)->current = g_list_next
     (GPA_KEY_OPERATION (op)->current);
   gpa_key_expire_operation_next (op);
