@@ -47,16 +47,21 @@ confirm_delete_secret (GtkWidget * parent)
                                         GTK_RESPONSE_NO,
                                         NULL);
   gtk_dialog_set_default_response (GTK_DIALOG (window), GTK_RESPONSE_NO);
-  hbox = gtk_hbox_new (FALSE, 10);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 10);
-  gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_image_new_from_stock
-                               (GTK_STOCK_DIALOG_WARNING, 
-                                GTK_ICON_SIZE_DIALOG));
+
+  GtkWidget *image_warning;
+  image_warning = gtk_image_new_from_icon_name ("dialog-warning", GTK_ICON_SIZE_DIALOG);
+
+  gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (image_warning), TRUE, TRUE, 0);
   label = gtk_label_new (_("If you delete this key, you won't be able to\n"
                            "read messages encrypted with it.\n\n"
                            "Are you really sure you want to delete it?"));
-  gtk_box_pack_start_defaults (GTK_BOX (hbox), label);
-  gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (window)->vbox), hbox);
+  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+
+  GtkBox *box = GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (window)));
+
+  gtk_box_pack_start(GTK_BOX (box), hbox, TRUE, TRUE, 0);
   gtk_widget_show_all (window);
   if (gtk_dialog_run (GTK_DIALOG (window)) == GTK_RESPONSE_YES)
     {
@@ -98,12 +103,14 @@ gpa_delete_dialog_run (GtkWidget * parent, gpgme_key_t key)
   gtk_dialog_set_default_response (GTK_DIALOG (window), GTK_RESPONSE_YES);
   gtk_container_set_border_width (GTK_CONTAINER (window), 5);
 
-  vbox = GTK_DIALOG (window)->vbox;
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (window));
+  // vbox = GTK_DIALOG (window)->vbox;
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
   label = gtk_label_new (_("You have selected the following key "
 			   "for removal:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 5);
   
   info = gpa_key_info_new (key);
@@ -114,7 +121,8 @@ gpa_delete_dialog_run (GtkWidget * parent, gpgme_key_t key)
       label = gtk_label_new (_("This key has a secret key."
 			       " Deleting this key cannot be undone,"
 			       " unless you have a backup copy."));
-      gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+      gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+      gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
       gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
       gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 5);
     }
@@ -124,7 +132,8 @@ gpa_delete_dialog_run (GtkWidget * parent, gpgme_key_t key)
 			       " Deleting this key cannot be undone easily,"
 			       " although you may be able to get a new copy "
 			       " from the owner or from a key server."));
-      gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+      gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+      gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
       gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
       gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 5);
     }
