@@ -209,7 +209,6 @@ gpa_keylist_init (GTypeInstance *instance, void *class_ptr)
 
   /* Setup the view.  */
   gtk_tree_view_set_model (GTK_TREE_VIEW (list), GTK_TREE_MODEL (store));
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (list), TRUE);
   gpa_keylist_set_brief (list);
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
@@ -236,9 +235,9 @@ gpa_keylist_init (GTypeInstance *instance, void *class_ptr)
        * We must forcefully load the secret keytable first to
        * prevent concurrent access to the TOFU database. */
       gpa_keytable_force_reload (gpa_keytable_get_secret_instance (),
-                                 NULL, (GpaKeyTableEndFunc) gtk_main_quit,
+                                 NULL, (GpaKeyTableEndFunc) g_application_quit,
                                  NULL);
-      gtk_main ();
+      // gtk_main ();
 
       /* Now we can load the public keyring. */
       gpa_keytable_list_keys (gpa_keytable_get_public_instance(),
@@ -405,11 +404,11 @@ get_key_pixbuf (gpgme_key_t key)
   if (seckey)
     {
       if (seckey->subkeys && seckey->subkeys->is_cardkey)
-        return GPA_STOCK_SECRET_CARDKEY;
-      return GPA_STOCK_SECRET_KEY;
+        return "blue_yellow_cardkey"; //GPA_STOCK_SECRET_CARDKEY;
+      return "blue_yellow_key"; //GPA_STOCK_SECRET_KEY;
     }
   else
-    return GPA_STOCK_PUBLIC_KEY;
+    return "blue_key"; //GPA_STOCK_PUBLIC_KEY;
 }
 
 
@@ -574,14 +573,19 @@ search_keylist_function (GtkTreeModel *model, gint column,
   gboolean result = TRUE;
   gchar *user_id;
   gint search_len;
+  const char *s;
 
   gtk_tree_model_get (model, iter,
                       GPA_KEYLIST_COLUMN_USERID, &user_id, -1);
 
   search_len = strlen (key_to_search_for);
 
+  /* Note that we also search for a mail address.  */
   if (!g_ascii_strncasecmp (user_id, key_to_search_for, search_len))
     result=FALSE;
+  else if ((s = strchr (user_id, '<')) && s[1]
+           && !g_ascii_strncasecmp (s+1, key_to_search_for, search_len))
+    result=FALSE;
 
   g_free (user_id);
 
@@ -606,7 +610,8 @@ setup_columns (GpaKeyList *keylist, gboolean detailed)
       g_object_set (renderer, "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
 
       column = gtk_tree_view_column_new_with_attributes
-        (NULL, renderer, "stock-id",
+        //(NULL, renderer, "stock-id",
+        (NULL, renderer, "icon-name",
          GPA_KEYLIST_COLUMN_IMAGE,
          NULL);
       gtk_tree_view_append_column (GTK_TREE_VIEW (keylist), column);
@@ -914,7 +919,7 @@ gpa_keylist_new_key (GpaKeyList * keylist, const char *fpr)
 
   add_trustdb_dialog (keylist);
   gpa_keytable_load_new (gpa_keytable_get_secret_instance (), fpr,
-			 NULL, (GpaKeyTableEndFunc) gtk_main_quit, NULL);
+			 NULL, (GpaKeyTableEndFunc) g_application_quit, NULL);
   /* Hack. Turn the asynchronous listing into a synchronous one */
   gtk_main ();
   remove_trustdb_dialog (keylist);
@@ -933,10 +938,10 @@ gpa_keylist_imported_secret_key (GpaKeyList *keylist)
   /* KEYLIST is currently not used. */
 
   gpa_keytable_load_new (gpa_keytable_get_secret_instance (), NULL,
-			 NULL, (GpaKeyTableEndFunc) gtk_main_quit, NULL);
+			 NULL, (GpaKeyTableEndFunc) g_application_quit, NULL);
   /* Hack. Turn the asynchronous listing into a synchronous one */
   /* FIXME:  Does that work well with the server shutdown code? */
-  gtk_main ();
+  // gtk_main ();
 }
 
 
