@@ -118,8 +118,12 @@ gpa_file_verify_dialog_constructor (GType type,
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
   dialog->notebook = gtk_notebook_new ();
-  gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-			       dialog->notebook);
+
+  //vboxEncrypt = gtk_dialog_get_content_area(dialog);
+  GtkWidget *box = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
+  gtk_box_pack_start (GTK_BOX (box),
+			       dialog->notebook, TRUE, TRUE, 0);
   /* Hide on response */
   g_signal_connect (G_OBJECT (dialog), "response",
 		    G_CALLBACK (gtk_widget_hide), NULL);
@@ -329,7 +333,6 @@ signature_list (gpgme_signature_t sigs, gpgme_ctx_t ctx)
   store = gtk_list_store_new (SIG_N_COLUMNS, G_TYPE_STRING,
 			      G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
   list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (list), TRUE);
   gtk_widget_set_size_request (list, 400, 100);
 
   renderer = gtk_cell_renderer_text_new ();
@@ -370,7 +373,7 @@ verify_file_page (gpgme_signature_t sigs, const gchar *signed_file,
   GtkWidget *label;
   GtkWidget *scrolled;
 
-  vbox = gtk_vbox_new (FALSE, 5);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
   if (signed_file)
@@ -378,17 +381,18 @@ verify_file_page (gpgme_signature_t sigs, const gchar *signed_file,
       gchar *text = g_strdup_printf (_("Verified data in file: %s"),
 				     signed_file);
       label = gtk_label_new (text);
-      gtk_box_pack_start_defaults (GTK_BOX (vbox), label);
+      gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
       g_free (text);
       text = g_strdup_printf (_("Signature: %s"), signature_file);
       label = gtk_label_new (text);
-      gtk_box_pack_start_defaults (GTK_BOX (vbox), label);
+      gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
       g_free (text);
     }
 
   label = gtk_label_new (_("Signatures:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-  gtk_box_pack_start_defaults (GTK_BOX (vbox), label);
+  gtk_widget_set_halign (GTK_WIDGET (label), 0.0);
+  gtk_widget_set_valign (GTK_WIDGET (label), 0.5);
+  gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 
   list = signature_list (sigs, ctx);
   scrolled = gtk_scrolled_window_new (NULL, NULL);
@@ -398,7 +402,7 @@ verify_file_page (gpgme_signature_t sigs, const gchar *signed_file,
                                   GTK_POLICY_AUTOMATIC,
                                   GTK_POLICY_AUTOMATIC);
   gtk_container_add (GTK_CONTAINER (scrolled), list);
-  gtk_box_pack_start_defaults (GTK_BOX (vbox), scrolled);
+  gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
 
   return vbox;
 }
